"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InstanceStatsService = void 0;
const js_sha256_1 = require("js-sha256");
const types_1 = require("../../types");
const util_1 = require("../../util");
const date_fns_1 = require("date-fns");
class InstanceStatsService {
    constructor({ featureToggleStore, userStore, projectStore, environmentStore, strategyStore, contextFieldStore, groupStore, segmentStore, roleStore, settingStore, clientInstanceStore, eventStore, apiTokenStore, clientMetricsStoreV2, featureStrategiesReadModel, trafficDataUsageStore, }, { getLogger, flagResolver, }, versionService, getActiveUsers, getProductionChanges) {
        this.strategyStore = strategyStore;
        this.userStore = userStore;
        this.featureToggleStore = featureToggleStore;
        this.environmentStore = environmentStore;
        this.projectStore = projectStore;
        this.groupStore = groupStore;
        this.contextFieldStore = contextFieldStore;
        this.segmentStore = segmentStore;
        this.roleStore = roleStore;
        this.versionService = versionService;
        this.settingStore = settingStore;
        this.eventStore = eventStore;
        this.clientInstanceStore = clientInstanceStore;
        this.logger = getLogger('services/stats-service.js');
        this.getActiveUsers = getActiveUsers;
        this.getProductionChanges = getProductionChanges;
        this.apiTokenStore = apiTokenStore;
        this.clientMetricsStore = clientMetricsStoreV2;
        this.flagResolver = flagResolver;
        this.featureStrategiesReadModel = featureStrategiesReadModel;
        this.trafficDataUsageStore = trafficDataUsageStore;
    }
    getProjectModeCount() {
        return this.projectStore.getProjectModeCounts();
    }
    getToggleCount() {
        return this.featureToggleStore.count({
            archived: false,
        });
    }
    getArchivedToggleCount() {
        return this.featureToggleStore.count({
            archived: true,
        });
    }
    async hasOIDC() {
        const settings = await this.settingStore.get('unleash.enterprise.auth.oidc');
        return settings?.enabled || false;
    }
    async hasSAML() {
        const settings = await this.settingStore.get('unleash.enterprise.auth.saml');
        return settings?.enabled || false;
    }
    async getStats() {
        const versionInfo = await this.versionService.getVersionInfo();
        const [featureToggles, archivedFeatureToggles, users, serviceAccounts, apiTokens, activeUsers, projects, contextFields, groups, roles, customRootRoles, customRootRolesInUse, environments, segments, strategies, SAMLenabled, OIDCenabled, clientApps, featureExports, featureImports, productionChanges, previousDayMetricsBucketsCount, maxEnvironmentStrategies, maxConstraintValues, maxConstraints,] = await Promise.all([
            this.getToggleCount(),
            this.getArchivedToggleCount(),
            this.getRegisteredUsers(),
            this.countServiceAccounts(),
            this.countApiTokensByType(),
            this.getActiveUsers(),
            this.getProjectModeCount(),
            this.contextFieldCount(),
            this.groupCount(),
            this.roleCount(),
            this.customRolesCount(),
            this.customRolesCountInUse(),
            this.environmentCount(),
            this.segmentCount(),
            this.strategiesCount(),
            this.hasSAML(),
            this.hasOIDC(),
            this.appCount ? this.appCount : this.getLabeledAppCounts(),
            this.eventStore.deprecatedFilteredCount({
                type: types_1.FEATURES_EXPORTED,
            }),
            this.eventStore.deprecatedFilteredCount({
                type: types_1.FEATURES_IMPORTED,
            }),
            this.getProductionChanges(),
            this.countPreviousDayHourlyMetricsBuckets(),
            this.featureStrategiesReadModel.getMaxFeatureEnvironmentStrategies(),
            this.featureStrategiesReadModel.getMaxConstraintValues(),
            this.featureStrategiesReadModel.getMaxConstraintsPerStrategy(),
        ]);
        return {
            timestamp: new Date(),
            instanceId: versionInfo.instanceId,
            versionOSS: versionInfo.current.oss,
            versionEnterprise: versionInfo.current.enterprise,
            users,
            serviceAccounts,
            apiTokens,
            activeUsers,
            featureToggles,
            archivedFeatureToggles,
            projects,
            contextFields,
            roles,
            customRootRoles,
            customRootRolesInUse,
            groups,
            environments,
            segments,
            strategies,
            SAMLenabled,
            OIDCenabled,
            clientApps: Object.entries(clientApps).map(([range, count]) => ({
                range: range,
                count,
            })),
            featureExports,
            featureImports,
            productionChanges,
            previousDayMetricsBucketsCount,
            maxEnvironmentStrategies: maxEnvironmentStrategies?.count ?? 0,
            maxConstraintValues: maxConstraintValues?.count ?? 0,
            maxConstraints: maxConstraints?.count ?? 0,
        };
    }
    groupCount() {
        return this.groupStore.count();
    }
    roleCount() {
        return this.roleStore.count();
    }
    customRolesCount() {
        return this.roleStore.filteredCount({ type: util_1.CUSTOM_ROOT_ROLE_TYPE });
    }
    customRolesCountInUse() {
        return this.roleStore.filteredCountInUse({
            type: util_1.CUSTOM_ROOT_ROLE_TYPE,
        });
    }
    segmentCount() {
        return this.segmentStore.count();
    }
    contextFieldCount() {
        return this.contextFieldStore.count();
    }
    strategiesCount() {
        return this.strategyStore.count();
    }
    environmentCount() {
        return this.environmentStore.count();
    }
    countPreviousDayHourlyMetricsBuckets() {
        return this.clientMetricsStore.countPreviousDayHourlyMetricsBuckets();
    }
    countApiTokensByType() {
        return this.apiTokenStore.countByType();
    }
    getRegisteredUsers() {
        return this.userStore.count();
    }
    countServiceAccounts() {
        return this.userStore.countServiceAccounts();
    }
    async getCurrentTrafficData() {
        const traffic = await this.trafficDataUsageStore.getTrafficDataUsageForPeriod((0, date_fns_1.format)(new Date(), 'yyyy-MM'));
        const counts = traffic.map((item) => item.count);
        return counts.reduce((total, current) => total + current, 0);
    }
    async getLabeledAppCounts() {
        const [t7d, t30d, allTime] = await Promise.all([
            this.clientInstanceStore.getDistinctApplicationsCount(7),
            this.clientInstanceStore.getDistinctApplicationsCount(30),
            this.clientInstanceStore.getDistinctApplicationsCount(),
        ]);
        this.appCount = {
            '7d': t7d,
            '30d': t30d,
            allTime,
        };
        return this.appCount;
    }
    getAppCountSnapshot(range) {
        return this.appCount?.[range];
    }
    async getSignedStats() {
        const instanceStats = await this.getStats();
        const totalProjects = instanceStats.projects
            .map((p) => p.count)
            .reduce((a, b) => a + b, 0);
        const sum = (0, js_sha256_1.sha256)(`${instanceStats.instanceId}${instanceStats.users}${instanceStats.featureToggles}${totalProjects}${instanceStats.roles}${instanceStats.groups}${instanceStats.environments}${instanceStats.segments}`);
        return { ...instanceStats, sum, projects: totalProjects };
    }
}
exports.InstanceStatsService = InstanceStatsService;
//# sourceMappingURL=instance-stats-service.js.map